Core record, command, event, field, and accessor model types.
Structs
- Access
Error - Buffer access error used by generated readers.
- Command
- Runtime command value with kind, external sequence, external time, and payload.
- Command
Definition - Static definition for one command type.
- Enum
Decode Error - Error returned when an encoded enum discriminant is unknown.
- Enum
Definition - Static definition for one generated
repr(u8)enum. - Enum
Variant Definition - Static definition for one
repr(u8)enum variant. - Event
- Runtime event value emitted by a command transaction.
- Event
Definition - Static definition for one event type.
- Event
Frame - Event plus committed transaction sequence.
- Field
Definition - Static definition for one schema field.
- Fixed
Bytes - Fixed-capacity byte value with a logical length.
- Payload
Field Definition - Static definition for one command or event payload field.
- PkBuilder
- Incremental primary-key byte encoder.
- Record
Definition - Static definition for one record type.
- Record
Key - Fully qualified record key used by runtime hosts.
- Version
- Two-component schema version.
Enums
- Field
Type - Primitive field representation supported by StateVec schemas.
Constants
- RECORD_
HEADER_ SIZE - Number of bytes reserved by the runtime record header.
Traits
- Command
Schema - Trait implemented by generated command types.
- EnumU8
- Trait implemented by
#[derive(EnumU8)]. - Event
Schema - Trait implemented by generated event types.
- Generated
Command Access - Generated typed accessors for command payloads.
- Generated
Event Access - Generated typed accessors for event payloads.
- Generated
Record Access - Generated typed accessors for a fixed-layout record.
- PkCodec
- Primary-key encoding hook implemented by generated record types.
- Record
Schema - Trait implemented by generated record types.
Functions
- read_
bool - Reads a boolean from a fixed-layout buffer.
- read_
fixed_ bytes - Reads a fixed-capacity byte field from a fixed-layout buffer.
- read_
i32_ le - Reads a little-endian
i32from a fixed-layout buffer. - read_
i64_ le - Reads a little-endian
i64from a fixed-layout buffer. - read_u8
- Reads a
u8from a fixed-layout buffer. - read_
u16_ le - Reads a little-endian
u16from a fixed-layout buffer. - read_
u32_ le - Reads a little-endian
u32from a fixed-layout buffer. - read_
u64_ le - Reads a little-endian
u64from a fixed-layout buffer. - read_
u128_ le - Reads a little-endian
u128from a fixed-layout buffer. - read_
var_ bytes - Reads a payload-layer variable byte field and returns the field plus next offset.
- write_
bool - Writes a boolean into a fixed-layout buffer.
- write_
fixed_ bytes - Writes a fixed-capacity byte field into a fixed-layout buffer.
- write_
i32_ le - Writes a little-endian
i32into a fixed-layout buffer. - write_
i64_ le - Writes a little-endian
i64into a fixed-layout buffer. - write_
u8 - Writes a
u8into a fixed-layout buffer. - write_
u16_ le - Writes a little-endian
u16into a fixed-layout buffer. - write_
u32_ le - Writes a little-endian
u32into a fixed-layout buffer. - write_
u64_ le - Writes a little-endian
u64into a fixed-layout buffer. - write_
u128_ le - Writes a little-endian
u128into a fixed-layout buffer. - write_
var_ bytes - Appends a payload-layer variable byte field.
Type Aliases
- PkBytes
- Encoded primary-key bytes.
- PkEncode
Fn - Function pointer used by generated record schemas to encode primary keys.
- Record
Kind - Stable numeric kind assigned to a record type within a schema version.
- SysId
- Host-assigned system identifier for one materialized record.
- TxSeq
- Monotonic committed transaction sequence.